@@ -1,12 +1,13 @@
-# $Id: LibXML.pm,v 1.18 2001/07/20 16:03:57 matt Exp $
+# $Id: LibXML.pm,v 1.20 2001/08/07 08:54:56 matt Exp $
 
 package XML::LibXML;
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
 use Carp;
+use XML::LibXML::NodeList;
 
-$VERSION = "0.99";
+$VERSION = "1.00";
 require Exporter;
 require DynaLoader;
 
@@ -137,6 +138,28 @@ sub XML::LibXML::Node::iterator {
     return $rv;
 }
 
+sub XML::LibXML::Node::findnodes {
+    my ($node, $xpath) = @_;
+    my @nodes = $node->_findnodes($xpath);
+    if (wantarray) {
+        return @nodes;
+    }
+    else {
+        return XML::LibXML::NodeList->new(@nodes);
+    }
+}
+
+sub XML::LibXML::Node::findvalue {
+    my ($node, $xpath) = @_;
+    return $node->find($xpath)->to_literal->value;
+}
+
+sub XML::LibXML::Node::find {
+    my ($node, $xpath) = @_;
+    my ($type, @params) = $node->_find($xpath);
+    return $type->new(@params);
+}
+
 1;
 __END__
 
