@@ -1,4 +1,4 @@
-/* $Id: dom.c,v 1.16 2001/06/29 15:30:03 matt Exp $ */
+/* $Id: dom.c,v 1.18 2001/07/20 11:31:36 phish Exp $ */
 #include <libxml/tree.h>
 #include <libxml/encoding.h>
 #include <libxml/xmlmemory.h>
@@ -181,6 +181,11 @@ domDecodeString( const char *encoding, const xmlChar *string){
  * leader and followup has to be followups in the nodelist!!!
  * the function returns the node inserted. if a fragment was inserted,
  * the first node of the list will returned
+ *
+ * i ran into a misconception here. there should be a normalization function
+ * for the DOM, so sequences of text nodes can get replaced by a single 
+ * text node. as i see DOM Level 1 does not allow text node sequences, while
+ * Level 2 and 3 do.
  **/
 xmlNodePtr 
 insert_node_to_nodelist( xmlNodePtr lead, xmlNodePtr node, xmlNodePtr follow ){
@@ -222,49 +227,16 @@ insert_node_to_nodelist( xmlNodePtr lead, xmlNodePtr node, xmlNodePtr follow ){
       par->children = cld1;
     }
     else {
-      if( lead->type == XML_TEXT_NODE && cld1->type == XML_TEXT_NODE ){
-        xmlChar * content = cld1->content;
-        cld1->content = xmlStrdup(lead->content);
-        xmlNodeAddContent(cld1, content);
-        cld1->prev  = lead->prev;
-        if ( lead->prev == NULL ) {
-          par->children = cld1;
-        }
-        else {
-          lead->prev->next = cld1;
-        }
-        lead->next = lead->prev = lead->parent = NULL;
-        /* we won't free any nodes here, since perl stil might use them */ 
-        /* xmlFreeNode( lead ); */
-      }
-      else {
         lead->next = cld1;
         cld1->prev  = lead;
-      }
     }
   
     if ( follow == NULL ){
       par->last = cld2;
     } 
     else {
-      if( follow->type == XML_TEXT_NODE && cld2->type == XML_TEXT_NODE ){
-        xmlNodeAddContent(cld2, follow->content);
-
-        cld2->next  = follow->prev;
-        if ( follow->prev == NULL ) {
-          par->last = cld2;
-        }
-        else {
-          follow->next->prev = cld2;
-        }
-        follow->next = follow->prev = follow->parent = NULL;
-        /* we won't free any nodes here, since perl stil might use them */ 
-        /* xmlFreeNode( follow ); */
-      }
-      else {
-        follow->prev = cld2;
-        cld2->next  = follow;
-      }
+      follow->prev = cld2;
+      cld2->next  = follow;
     }
   }
 
@@ -349,7 +321,6 @@ domSetName( xmlNodePtr node, char* name ) {
   else {
     str = xmlStrdup( name );
   }
-  warn( str );
   node->name = str;
 }
 
@@ -628,19 +599,18 @@ domReplaceNode( xmlNodePtr oldnode, xmlNodePtr newnode ){
 
 void
 domSetNodeValue( xmlNodePtr n , xmlChar* val ){
-  char* ctnt = NULL; 
-
   if ( n == NULL ) 
     return;
-
-  ctnt = xmlEncodeEntitiesReentrant( n->doc , val );
+  if ( val == NULL ){
+    val = "";
+  }
   
   if( n->type == XML_ATTRIBUTE_NODE ){
     if ( n->children != NULL ) {
       n->last = NULL;
       xmlFreeNodeList( n->children );
     }
-    n->children = xmlNewText( ctnt );
+    n->children = xmlNewText( val );
     n->children->parent = n;
     n->children->doc = n->doc;
     n->last = n->children; 
@@ -648,7 +618,8 @@ domSetNodeValue( xmlNodePtr n , xmlChar* val ){
   else if( n->content != NULL ) {
     /* free old content */
     xmlFree( n->content );
-    n->content = xmlStrdup(ctnt);
+    n->content = xmlStrdup(val);
+
   }
 }
 
